Arcovid19
=========

|Build Status| |Python 3| |BSD-3| |Documentation Status| |PyPI|

This library contains the utilities to access different
Argentina-Related databases of COVID-19 data from the IATE task force.

Installation
------------

.. code:: bash

    $ pip install arcovid19

Authors
-------

-  Juan B Cabral (CIFASIS-UNR, IATE-OAC-UNC).
-  Mauricio Koraj (Liricus SRL.).
-  Vanessa Daza (IATE-OAC-UNC, FaMAF-UNC).
-  Mariano Dominguez (IATE-OAC-UNC, FaMAF-UNC).
-  Marcelo Lares (IATE-OAC-UNC, FaMAF-UNC).
-  Nadia Luczywo (LIMI-FCEFyN-UNC, IED-FCE-UNC, FCA-IUA-UNDEF)
-  Dante Paz (IATE-OAC-UNC, FaMAF-UNC).
-  Rodrigo Quiroga (INFIQC-CFQ, FCQ-UNC).
-  Martín de los Ríos (ICTP-SAIFR).
-  Bruno Sanchez (Department of Physics, Duke University).
-  Federico Stasyszyn (IATE-OAC, FaMAF-UNC).

Documentation
-------------

Check our documentation and tutorial here:
https://arcovid19.readthedocs.io/

Raw Data
--------

-  `Viewer <https://docs.google.com/spreadsheets/d/e/2PACX-1vTfinng5SDBH9RSJMHJk28dUlW3VVSuvqaBSGzU-fYRTVLCzOkw1MnY17L2tWsSOppHB96fr21Ykbyv/pub>`__
-  `CSV <https://raw.githubusercontent.com/ivco19/libs/master/databases/cases.csv>`__
-  `XLSX <https://raw.githubusercontent.com/ivco19/libs/master/databases/cases.xlsx>`__

Citation
--------

Please acknowledge arcovid19 in any research report or publication that
requires citation of any author's work. Our suggested acknowledgment is:

    The authors acknowledge the arcovid19 project that contributed to
    the research reported here. https://github.com/ivco19/libs/

ABOUT THE DATA
~~~~~~~~~~~~~~

Please cite:

    Luczywo, N. A., Daza, V., Koraj, M., Dominguez, M., Lares, M., Paz,
    D. J., Quiroga, R., Rios, M. E. D. L., Sánchez, B. O., Stasyszyn,
    F., & Cabral, J. B. (2020). Infecciones de COVID-19 en Argentina.
    Unpublished. https://doi.org/10.13140/RG.2.2.22519.78246

::

        @misc{https://doi.org/10.13140/rg.2.2.22519.78246,
            doi = {10.13140/RG.2.2.22519.78246},
            url = {http://rgdoi.net/10.13140/RG.2.2.22519.78246},
            author = {
                Luczywo,  Nadia Ayelen and Daza,  Vanessa and Koraj,  Mauricio and
                Dominguez,  Mariano and Lares,  Marcelo and Paz,  Dante Javier and
                Quiroga,  Rodrigo and Rios,  Martín Emilio De Los and
                Sánchez,  Bruno Orlando and Stasyszyn,  Federico and
                Cabral,  Juan Bautista},
            language = {es},
            title = {Infecciones de COVID-19 en Argentina},
            publisher = {Unpublished},
            year = {2020}
        }

**Afiliations:**

-  `Centro Franco Argentino de Ciencias de la Información y de Sistemas
   (CIFASIS-UNR) <https://www.cifasis-conicet.gov.ar/>`__
-  `Instituto de Astronomía Téorico y Experimental
   (IATE-OAC-UNC) <http://iate.oac.uncor.edu/>`__
-  `Facultad de Matemática Física y Computación
   (FaMAF-UNC) <https://www.famaf.unc.edu.ar/>`__
-  `Laboratorio de Ingeniería y Mantenimiento Industrial
   (LIMI-FCEFyN-UNC) <https://fcefyn.unc.edu.ar/facultad/secretarias/investigacion-y-posgrado/-investigacion/laboratorio-de-ingenieria-y-mantenimiento-industrial/>`__
-  `Instituto De Estadística Y Demografía - Facultad de Ciencias
   Económicas
   (IED-FCE-UNC) <http://www.eco.unc.edu.ar/instituto-de-estadistica-y-demografia>`__
-  `Department of Physics, Duke University <https://phy.duke.edu/>`__
-  `Facultad de Ciencias de la Administación
   (FCA-IUA-UNDEF) <https://www.iua.edu.ar/>`__
-  `Instituto de Investigaciones en Físico-Química de Córdoba
   (INFIQC-CONICET) <http://infiqc-fcq.psi.unc.edu.ar/>`__
-  `Liricus SRL <http://www.liricus.com.ar/>`__
-  `ICTP South American Institute for Fundamental Research
   (ICTP-SAIFR) <ICTP-SAIFR>`__

.. |Build Status| image:: https://travis-ci.org/ivco19/libs.svg?branch=master
   :target: https://travis-ci.org/ivco19/libs
.. |Python 3| image:: https://img.shields.io/badge/python-3.7+-blue.svg
   :target: https://badge.fury.io/py/arcovid19
.. |BSD-3| image:: https://img.shields.io/badge/License-BSD3-blue.svg
   :target: https://tldrlegal.com/license/bsd-3-clause-license-(revised)
.. |Documentation Status| image:: https://readthedocs.org/projects/arcovid19/badge/?version=latest
   :target: https://arcovid19.readthedocs.io/en/latest/?badge=latest
.. |PyPI| image:: https://img.shields.io/pypi/v/arcovid19
   :target: https://pypi.org/project/arcovid19/
